/* 
 * Copyright (c) 2010, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
/*
 *  ======== ti/sdo/ce/CERuntime.h ========
 */

/**
 *  @file       ti/sdo/ce/CERuntime.h
 *
 *  @brief      The Codec Engine Runtime init module.  Provides system
 *              wide initialization of the Codec Engine Runtime.
 */
/**
 *  @addtogroup   CODECENGINE     Codec Engine Runtime
 */

#ifndef CERuntime_
#define CERuntime_

#ifdef __cplusplus
extern "C" {
#endif

/** @ingroup    CODECENGINE */
/*@{*/

/*
 *  ======== CERuntime_exit ========
 */
/**
 *  @brief      Exit the Codec Engine Runtime.
 *
 *  @remarks    This function finalizes the Codec Engine modules used in
 *              the current configuration.
 */
extern Void CERuntime_exit(Void);


/*
 *  ======== CERuntime_init ========
 */
/**
 *  @brief      Initialize the Codec Engine Runtime.
 *
 *  @remarks    This function must be called prior to using any Codec Engine
 *              APIs; it initializes all Codec Engine modules used in the
 *              the current configuration.
 */
extern Void CERuntime_init(Void);

/*@}*/

#ifdef __cplusplus
}
#endif

#endif
/*
 *  @(#) ti.sdo.ce; 1, 0, 6,403; 5-29-2010 19:37:41; /db/atree/library/trees/ce/ce-o13x/src/
 */

